@@ -1,14 +1,10 @@
 library(testthat)
-context("Read Oneshot EAV")
 
-credential <- REDCapR::retrieve_credential_local(
-  path_credential = system.file("misc/example.credentials", package="REDCapR"),
-  project_id      = 153
-)
+credential  <- retrieve_credential_testing()
 
 test_that("smoke test", {
   testthat::skip_on_cran()
-  returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, verbose=T)
+  returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token)
 })
 test_that("default", {
   testthat::skip_on_cran()
@@ -27,7 +23,7 @@ test_that("default", {
     comments = c("Character in a book, with some guessing", "A mouse character from a good book",
     "completely made up", "This record doesn't have a DAG assigned\n\nSo call up Trudy on the telephone\nSend her a letter in the mail",
     "Had a hand for trouble and a eye for cash\n\nHe had a gold watch chain and a black mustache"
-    ), mugshot = 7610:7614, race___1 = c(FALSE, FALSE, FALSE,
+    ), mugshot = c(197977L, 197978L, 197979L, 198002L, 198021L), race___1 = c(FALSE, FALSE, FALSE,
     FALSE, TRUE), race___2 = c(FALSE, FALSE, FALSE, TRUE, FALSE
     ), race___3 = c(FALSE, TRUE, FALSE, FALSE, FALSE), race___4 = c(FALSE,
     FALSE, TRUE, FALSE, FALSE), race___5 = c(TRUE, TRUE, TRUE,
@@ -46,7 +42,10 @@ test_that("default", {
 
   expect_message(
     regexp           = expected_outcome_message,
-    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, verbose=T)
+    returned_object <- REDCapR:::redcap_read_oneshot_eav(
+      redcap_uri  = credential$redcap_uri,
+      token       = credential$token
+    )
   )
 
   expect_equal(returned_object$data, expected=expected_data_frame) # dput(returned_object$data)
@@ -121,7 +120,7 @@ test_that("raw", {
     comments = c("Character in a book, with some guessing", "A mouse character from a good book",
     "completely made up", "This record doesn't have a DAG assigned\n\nSo call up Trudy on the telephone\nSend her a letter in the mail",
     "Had a hand for trouble and a eye for cash\n\nHe had a gold watch chain and a black mustache"
-    ), mugshot = 7610:7614, race___1 = c(FALSE, FALSE, FALSE,
+    ), mugshot = c(197977L, 197978L, 197979L, 198002L, 198021L), race___1 = c(FALSE, FALSE, FALSE,
     FALSE, TRUE), race___2 = c(FALSE, FALSE, FALSE, TRUE, FALSE
     ), race___3 = c(FALSE, TRUE, FALSE, FALSE, FALSE), race___4 = c(FALSE,
     FALSE, TRUE, FALSE, FALSE), race___5 = c(TRUE, TRUE, TRUE,
@@ -140,7 +139,7 @@ test_that("raw", {
 
   expect_message(
     regexp           = expected_outcome_message,
-    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, raw_or_label="raw", verbose=T)
+    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, raw_or_label="raw")
   )
 
   expect_equal(returned_object$data, expected=expected_data_frame, label="The returned data.frame should be correct") # dput(returned_object$data)
@@ -169,7 +168,7 @@ test_that("raw and DAG", {
     comments = c("Character in a book, with some guessing", "A mouse character from a good book",
     "completely made up", "This record doesn't have a DAG assigned\n\nSo call up Trudy on the telephone\nSend her a letter in the mail",
     "Had a hand for trouble and a eye for cash\n\nHe had a gold watch chain and a black mustache"
-    ), mugshot = 7610:7614, race___1 = c(FALSE, FALSE, FALSE,
+    ), mugshot = c(197977L, 197978L, 197979L, 198002L, 198021L), race___1 = c(FALSE, FALSE, FALSE,
     FALSE, TRUE), race___2 = c(FALSE, FALSE, FALSE, TRUE, FALSE
     ), race___3 = c(FALSE, TRUE, FALSE, FALSE, FALSE), race___4 = c(FALSE,
     FALSE, TRUE, FALSE, FALSE), race___5 = c(TRUE, TRUE, TRUE,
@@ -188,7 +187,7 @@ test_that("raw and DAG", {
 
   expect_message(
     regexp           = expected_outcome_message,
-    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, raw_or_label="raw", export_data_access_groups=TRUE, verbose=T)
+    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, raw_or_label="raw", export_data_access_groups=TRUE)
   )
 
   expect_equal(returned_object$data, expected=expected_data_frame, label="The returned data.frame should be correct") # dput(returned_object$data)
@@ -217,7 +216,7 @@ test_that("label and DAG", {
     24.7, 19.8, 27.9), comments = c("Character in a book, with some guessing",
     "A mouse character from a good book", "completely made up", "This record doesn't have a DAG assigned\n\nSo call up Trudy on the telephone\nSend her a letter in the mail",
     "Had a hand for trouble and a eye for cash\n\nHe had a gold watch chain and a black mustache"
-    ), mugshot = 7610:7614, race___1 = c(FALSE, FALSE, FALSE, FALSE,
+    ), mugshot = c(197977L, 197978L, 197979L, 198002L, 198021L), race___1 = c(FALSE, FALSE, FALSE, FALSE,
     FALSE), race___2 = c(FALSE, FALSE, FALSE, FALSE, FALSE), race___3 = c(FALSE,
     FALSE, FALSE, FALSE, FALSE), race___4 = c(FALSE, FALSE, FALSE,
     FALSE, FALSE), race___5 = c(FALSE, FALSE, FALSE, FALSE, FALSE
@@ -238,7 +237,7 @@ test_that("label and DAG", {
 
   expect_message(
     regexp           = expected_outcome_message,
-    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, raw_or_label="label", export_data_access_groups=TRUE, verbose=T)
+    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, raw_or_label="label", export_data_access_groups=TRUE)
   )
 
   expect_equal(returned_object$data, expected=expected_data_frame, label="The returned data.frame should be correct") # dput(returned_object$data)
@@ -267,7 +266,7 @@ test_that("label header", {
     comments = c("Character in a book, with some guessing", "A mouse character from a good book",
     "completely made up", "This record doesn't have a DAG assigned\n\nSo call up Trudy on the telephone\nSend her a letter in the mail",
     "Had a hand for trouble and a eye for cash\n\nHe had a gold watch chain and a black mustache"
-    ), mugshot = 7610:7614, race___1 = c(FALSE, FALSE, FALSE,
+    ), mugshot = c(197977L, 197978L, 197979L, 198002L, 198021L), race___1 = c(FALSE, FALSE, FALSE,
     FALSE, TRUE), race___2 = c(FALSE, FALSE, FALSE, TRUE, FALSE
     ), race___3 = c(FALSE, TRUE, FALSE, FALSE, FALSE), race___4 = c(FALSE,
     FALSE, TRUE, FALSE, FALSE), race___5 = c(TRUE, TRUE, TRUE,
@@ -307,7 +306,7 @@ test_that("filter - numeric", {
     ), dob = c("1934-04-09", "1952-11-02"), age = c(80L, 61L), sex = c(1L,
     0L), height = c(180L, 165L), weight = c(80L, 54L), bmi = c(24.7,
     19.8), comments = c("completely made up", "This record doesn't have a DAG assigned\n\nSo call up Trudy on the telephone\nSend her a letter in the mail"
-    ), mugshot = 7612:7613, race___1 = c(FALSE, FALSE), race___2 = c(FALSE,
+    ), mugshot = c(197979L, 198002L), race___1 = c(FALSE, FALSE), race___2 = c(FALSE,
     TRUE), race___3 = c(FALSE, FALSE), race___4 = c(TRUE, FALSE),
     race___5 = c(TRUE, TRUE), race___6 = c(FALSE, FALSE), ethnicity = 0:1,
     demographics_complete = c(2L, 2L), health_complete = c(2L,
@@ -323,7 +322,7 @@ test_that("filter - numeric", {
   filter <- "[age] >= 61"
   expect_message(
     regexp           = expected_outcome_message,
-    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, verbose=T, filter_logic=filter)
+    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, filter_logic=filter)
   )
 
   expect_equal(returned_object$data, expected=expected_data_frame, label="The returned data.frame should be correct") # dput(returned_object$data)
@@ -341,7 +340,7 @@ test_that("filter - character", {
     address = "Hotel Suite\nNew Orleans LA, 70115", telephone = "(405) 321-5555",
     email = "left@hippocket.com", dob = "1955-04-15", age = 59L,
     sex = 1L, height = 193.04, weight = 104L, bmi = 27.9, comments = "Had a hand for trouble and a eye for cash\n\nHe had a gold watch chain and a black mustache",
-    mugshot = 7614L, race___1 = TRUE, race___2 = FALSE, race___3 = FALSE,
+    mugshot = 198021L, race___1 = TRUE, race___2 = FALSE, race___3 = FALSE,
     race___4 = FALSE, race___5 = FALSE, race___6 = TRUE, ethnicity = 2L,
     demographics_complete = 2L, health_complete = 0L, race_and_ethnicity_complete = 2L), .Names = c("record_id",
     "name_first", "name_last", "address", "telephone", "email", "dob",
@@ -355,7 +354,7 @@ test_that("filter - character", {
   filter <- "[name_first] = 'John Lee'"
   expect_message(
     regexp           = expected_outcome_message,
-    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, verbose=T, filter_logic=filter)
+    returned_object <- REDCapR:::redcap_read_oneshot_eav(redcap_uri=credential$redcap_uri, token=credential$token, filter_logic=filter)
   )
 
   expect_equal(returned_object$data, expected=expected_data_frame, label="The returned data.frame should be correct") # dput(returned_object$data)
@@ -367,3 +366,17 @@ test_that("filter - character", {
   expect_match(returned_object$outcome_message, regexp=expected_outcome_message, perl=TRUE)
   expect_true(returned_object$success)
 })
+test_that("bad token -Error", {
+  testthat::skip_on_cran()
+
+  expected_outcome_message <- "The REDCapR record export operation was not successful\\."
+  expect_error(
+    regexp           = expected_outcome_message,
+    REDCapR:::redcap_read_oneshot_eav(
+      redcap_uri    = credential$redcap_uri,
+      token         = "BAD00000000000000000000000000000"
+    )
+  )
+})
+
+rm(credential)
